Module: Simplewoo::Client::Match
- Included in:
- Simplewoo::Client
- Defined in:
- lib/simplewoo/client/match.rb
Instance Method Summary collapse
-
#match_for_slider(id, options = {}) ⇒ Hashie::Mash
(also: #match)
Returns the matched entities and matched personalities for the slider.
Instance Method Details
#match_for_slider(id, options = {}) ⇒ Hashie::Mash Also known as: match
Returns the matched entities and matched personalities for the slider
12 13 14 |
# File 'lib/simplewoo/client/match.rb', line 12 def (id, = {}) get("/sliders/#{id}/match", ) end |